=== modified file 'NEWS'
--- NEWS	2007-08-28 12:19:35 +0000
+++ NEWS	2007-08-28 14:35:10 +0000
@@ -54,6 +54,8 @@
       names ending in a '.' at the end of messages were confused with a
       full stop that may or not have been there. (Daniel Watkins, #129791)
 
+    * Fix ``status FILE -r X..Y``. (Lukáš Lalinský)
+
   IMPROVEMENTS:
 
     * ``pull`` and ``merge`` are much faster at installing bundle format 4.

=== modified file 'bzrlib/tests/blackbox/test_status.py'
--- bzrlib/tests/blackbox/test_status.py	2007-08-08 02:00:07 +0000
+++ bzrlib/tests/blackbox/test_status.py	2007-08-28 14:37:01 +0000
@@ -230,6 +230,13 @@
         tof.seek(0)
         self.assertEquals(tof.readlines(), ['?   dir2/\n'])
 
+        tof = StringIO()
+        revs = [RevisionSpec.from_string('0'), RevisionSpec.from_string('1')]
+        show_tree_status(wt, specific_files=['test.c'], to_file=tof,
+                         short=True, revision=revs)
+        tof.seek(0)
+        self.assertEquals(tof.readlines(), ['+N  test.c\n'])
+
     def test_specific_files_conflicts(self):
         tree = self.make_branch_and_tree('.')
         self.build_tree(['dir2/'])

=== modified file 'bzrlib/tests/tree_implementations/test_tree.py'
--- bzrlib/tests/tree_implementations/test_tree.py	2007-08-20 14:27:40 +0000
+++ bzrlib/tests/tree_implementations/test_tree.py	2007-08-28 14:40:42 +0000
@@ -17,6 +17,7 @@
 from bzrlib import (
     errors,
     tests,
+    conflicts,
     )
 from bzrlib.tests import TestSkipped
 from bzrlib.tests.tree_implementations import TestCaseWithTree
@@ -142,3 +143,12 @@
         self.assertRaises(errors.NoSuchId, lambda: list(
                           tree.iter_files_bytes(
                           [('qux-id', 'file1-notpresent')])))
+
+
+class TestConflicts(TestCaseWithTree):
+
+    def test_conflicts(self):
+        """Tree.conflicts() should return a ConflictList instance."""
+        work_tree = self.make_branch_and_tree('wt')
+        tree = self._convert_tree(work_tree)
+        self.assertIsInstance(tree.conflicts(), conflicts.ConflictList)

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2007-08-20 13:47:09 +0000
+++ bzrlib/tree.py	2007-08-27 14:55:48 +0000
@@ -26,6 +26,7 @@
     delta,
     osutils,
     revision as _mod_revision,
+    conflicts as _mod_conflicts,
     symbol_versioning,
     )
 from bzrlib.decorators import needs_read_lock
@@ -104,7 +105,7 @@
 
         Each conflict is an instance of bzrlib.conflicts.Conflict.
         """
-        return []
+        return _mod_conflicts.ConflictList()
 
     def extras(self):
         """For trees that can have unversioned files, return all such paths."""

